
.. blogpost::
    :title: Build pythonnet
    :keywords: pythonnet
    :date: 2018-05-20
    :categories: module

    Building `pythonnet <https://github.com/pythonnet/pythonnet>`_
    on CircleCI was quite interesting.
    You can check the outcome on
    `sdpython/pythonnet <https://github.com/sdpython/pythonnet/tree/master>`_
    and get artifacts at
    `CircleCI/sdpython <https://circleci.com/gh/sdpython/pythonnet/tree/master>`_.
    The instructions are described in
    `.circleci/config.yml <https://github.com/sdpython/pythonnet/blob/master/.circleci/config.yml>`_.
